@@ -1,8 +1,5 @@
-from django.http import HttpResponseRedirect, HttpResponseServerError
-from django.urls import NoReverseMatch, reverse
-
-from allauth import app_settings as allauth_settings
 from allauth.account.stages import LoginStage
+from allauth.core.internal.httpkit import headed_redirect_response
 from allauth.mfa.models import Authenticator
 from allauth.mfa.utils import is_mfa_enabled
 from allauth.mfa.webauthn.internal.flows import did_use_passwordless_login
@@ -15,14 +12,7 @@ class AuthenticateStage(LoginStage):
     def handle(self):
         response, cont = None, True
         if self._should_handle(self.request):
-            try:
-                response = HttpResponseRedirect(reverse("mfa_authenticate"))
-            except NoReverseMatch:
-                if allauth_settings.HEADLESS_ONLY:
-                    # The response we would be rendering here is not actually used.
-                    response = HttpResponseServerError()
-                else:
-                    raise
+            response = headed_redirect_response("mfa_authenticate")
         return response, cont
 
     def _should_handle(self, request) -> bool:
