@@ -53,6 +53,9 @@ class GoogleTests(OAuth2TestsMixin, TestCase):
         self.email = "raymond.penners@example.com"
         self.identity_overwrites = {}
 
+    def get_expected_to_str(self):
+        return "raymond.penners@example.com"
+
     def get_google_id_token_payload(self):
         now = datetime.utcnow()
         client_id = "app123id"  # Matches `setup_app`
@@ -233,14 +236,14 @@ class AppInSettingsTests(GoogleTests):
 def test_login_by_token(db, client, settings_with_google_provider):
     client.cookies.load({"g_csrf_token": "csrf"})
     with patch(
-        "allauth.socialaccount.providers.google.views.jwt.get_unverified_header"
+        "allauth.socialaccount.internal.jwtkit.jwt.get_unverified_header"
     ) as g_u_h:
         with mocked_response({"dummykid": "-----BEGIN CERTIFICATE-----"}):
             with patch(
-                "allauth.socialaccount.providers.google.views.load_pem_x509_certificate"
+                "allauth.socialaccount.internal.jwtkit.load_pem_x509_certificate"
             ) as load_pem:
                 with patch(
-                    "allauth.socialaccount.providers.google.views.jwt.decode"
+                    "allauth.socialaccount.internal.jwtkit.jwt.decode"
                 ) as decode:
                     decode.return_value = {
                         "iss": "https://accounts.google.com",
@@ -307,6 +310,7 @@ def test_extract_data(
         (True, True, {"access_token": "123"}, "uid-from-userinfo", "pic-from-userinfo"),
     ],
 )
+@pytest.mark.parametrize("did_fetch_access_token", [False, True])
 def test_complete_login_variants(
     response,
     settings_with_google_provider,
@@ -315,6 +319,7 @@ def test_complete_login_variants(
     expected_uid,
     expected_picture,
     id_token_has_picture,
+    did_fetch_access_token,
 ):
     with patch.object(
         GoogleOAuth2Adapter,
@@ -327,16 +332,22 @@ def test_complete_login_variants(
         id_token = {"sub": "uid-from-id-token"}
         if id_token_has_picture:
             id_token["picture"] = "pic-from-id-token"
-        with patch.object(
-            GoogleOAuth2Adapter,
-            "_decode_id_token",
+        with patch(
+            "allauth.socialaccount.providers.google.views._verify_and_decode",
             return_value=id_token,
-        ):
+        ) as decode_mock:
             request = None
             app = None
             adapter = GoogleOAuth2Adapter(request)
+            adapter.did_fetch_access_token = did_fetch_access_token
             adapter.fetch_userinfo = fetch_userinfo
             token = SocialToken()
             login = adapter.complete_login(request, app, token, response)
             assert login.account.uid == expected_uid
             assert login.account.extra_data["picture"] == expected_picture
+            if not response.get("id_token"):
+                assert not decode_mock.called
+            else:
+                assert decode_mock.call_args[1]["verify_signature"] == (
+                    not did_fetch_access_token
+                )
